==> pocl_1.1.orig.tar.gz: pocl-1.1/lib/CL/clEnqueueTask.c <==
/* OpenCL runtime library: clEnqueueTask()

   Copyright (c) 2012-2017 pocl developers

   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
*/


#include "pocl_cl.h"


CL_API_ENTRY cl_int CL_API_CALL
POname(clEnqueueTask)(cl_command_queue   command_queue,
              cl_kernel          kernel,
              cl_uint            num_events_in_wait_list,
              const cl_event *   event_wait_list,
              cl_event *         event ) CL_API_SUFFIX__VERSION_1_0
{
  cl_int status;
  const size_t globalWS=1; 
  const size_t localWS=1; 

  status = POname(clEnqueueNDRangeKernel) (command_queue,
					   kernel, 
					   1 /*work_dim*/,
					   NULL /*global_work_offset*/,
					   &globalWS,
					   &localWS,
					   num_events_in_wait_list,
					   event_wait_list,
					   event);
  if (event)
    {
      (*event)->command_type = CL_COMMAND_TASK;
    }
  return status;
}
POsym(clEnqueueTask)

==> pocl_3.1.orig.tar.gz: pocl-3.1/lib/CL/clEnqueueTask.c <==
/* OpenCL runtime library: clEnqueueTask()

   Copyright (c) 2012-2017 pocl developers

   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
*/


#include "pocl_cl.h"


CL_API_ENTRY cl_int CL_API_CALL
POname(clEnqueueTask)(cl_command_queue   command_queue,
              cl_kernel          kernel,
              cl_uint            num_events_in_wait_list,
              const cl_event *   event_wait_list,
              cl_event *         event ) CL_API_SUFFIX__VERSION_1_0
{
  const size_t globalWS=1;
  const size_t localWS=1;

  return   POname(clEnqueueNDRangeKernel) (command_queue,
					   kernel, 
					   1 /*work_dim*/,
					   NULL /*global_work_offset*/,
					   &globalWS,
					   &localWS,
					   num_events_in_wait_list,
					   event_wait_list,
					   event);
}
POsym(clEnqueueTask)
